#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <alsa/asoundlib.h>
#define CHAN 4
#define BSIZ 4096	/* Number of frames */
main (int argc, char *argv[])
{
int i;
int err;
short buf[CHAN * BSIZ];
snd_pcm_t *playback_handle;
snd_pcm_hw_params_t *hw_params;
snd_output_t *log;              /* For the log goodie */

/* Just set it to something empty */
memset (buf, 0, sizeof(buf));
if ((err = snd_pcm_open (&playback_handle, argv[1], SND_PCM_STREAM_PLAYBACK, 0)) < 0) {
	fprintf (stderr, "cannot open audio device %s (%s)\n", 
	 argv[1], snd_strerror (err));
	exit (1);
	}
	   
if ((err = snd_pcm_hw_params_malloc (&hw_params)) < 0) {
	fprintf (stderr, "cannot allocate hardware parameter structure (%s)\n",
	 snd_strerror (err));
	exit (1);
	}
			 
if ((err = snd_pcm_hw_params_any (playback_handle, hw_params)) < 0) {
	fprintf (stderr, "cannot initialize hardware parameter structure (%s)\n",
	 snd_strerror (err));
	exit (1);
	}

if ((err = snd_pcm_hw_params_set_access (playback_handle, hw_params, SND_PCM_ACCESS_RW_INTERLEAVED)) < 0) {
	fprintf (stderr, "cannot set access type (%s)\n",
	 snd_strerror (err));
	exit (1);
	}

if ((err = snd_pcm_hw_params_set_format (playback_handle, hw_params, SND_PCM_FORMAT_S16_LE)) < 0) {
	fprintf (stderr, "cannot set sample format (%s)\n",
	 snd_strerror (err));
	exit (1);
	}

if ((err = snd_pcm_hw_params_set_rate_near (playback_handle, hw_params, 44100, 0)) < 0) {
	fprintf (stderr, "cannot set sample rate (%s)\n",
	 snd_strerror (err));
	exit (1);
	}

if ((err = snd_pcm_hw_params_set_channels (playback_handle, hw_params, CHAN)) < 0) {
	fprintf (stderr, "cannot set channel count (%s)\n",
	 snd_strerror (err));
	exit (1);
	}

if ((err = snd_pcm_hw_params (playback_handle, hw_params)) < 0) {
	fprintf (stderr, "cannot set parameters (%s)\n",
	 snd_strerror (err));
	exit (1);
	}
err = snd_output_stdio_attach(&log, stderr, 0);
if (err < 0)
	{
	fprintf (stderr, "Can\'t do stdio attach (%d)\n", err);
	exit (1);
	}
snd_pcm_dump (playback_handle, log);
      
/* snd_pcm_hw_params_free (hw_params); */

if ((err = snd_pcm_prepare (playback_handle)) < 0) {
	fprintf (stderr, "cannot prepare audio interface for use (%s)\n",
	 snd_strerror (err));
	exit (1);
	}

for (i = 0; i < 10; ++i) {
	if ((err = snd_pcm_writei (playback_handle, buf, BSIZ)) != BSIZ) {
		fprintf (stderr, "write to audio interface failed (%s)\n",
			 snd_strerror (err));
		exit (1);
		}
	}

snd_pcm_close (playback_handle);
exit (0);
}

